import{C as n,D as r,E as o,F as p,P as c,G as d,H as f,I as m,J as a,K as u,L as b,N as g,O as l}from"./jwt-decode.esm.7c9b757c.js";import{a as y,b as i}from"./router.6dc4e09a.js";import{s as w}from"./workspaceStore.7d445909.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.81eedc2c.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";import"./PlayerConfigProvider.be4efc80.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="12642372-2ba6-4102-91f3-f16bae1e523b",t._sentryDebugIdIdentifier="sentry-dbid-12642372-2ba6-4102-91f3-f16bae1e523b")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),s=n(),e=r({render:()=>u(h)});o.init(),p(e,i,t),I.init(),e.use(i),e.use(s),e.use(c),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",f),e.component("Message",m),a(e,b),a(e,g),a(e,l)})();
//# sourceMappingURL=player.f343a2a8.js.map
