import{O as l}from"./workspaceStore.7d445909.js";import{d as c,U as f,ac as u,f as n,b as o,u as a,o as _,g as r,t as i,i as s,A as b,df as p}from"./jwt-decode.esm.7c9b757c.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5937010a-43f9-4f5b-8fdb-96bf59e541cf",e._sentryDebugIdIdentifier="sentry-dbid-5937010a-43f9-4f5b-8fdb-96bf59e541cf")}catch{}})();const v=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(_(),u("div",null,[n(a(b),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(p),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLoginCallback.10d73f31.js.map
