import{_ as h}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.7d3bd819.js";import{A as v}from"./constants.6f371b22.js";import{d as A,c as w,ac as x,f as i,b as s,u as t,a as f,h as p,eA as I,ec as T,o as c,g as o,t as u,A as B,T as m,bY as C,e as E,dd as N,i as r,_ as D}from"./jwt-decode.esm.7c9b757c.js";import{u as S}from"./workspaceStore.7d445909.js";import{C as R}from"./Card.929a13fd.js";import"./Logo.2bc39bab.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},l=new L().stack;l&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[l]="246b8285-7c27-4962-89c3-fb57aad0efec",n._sentryDebugIdIdentifier="sentry-dbid-246b8285-7c27-4962-89c3-fb57aad0efec")}catch{}})();const V={class:"inner-content"},H={class:"card-content"},G=A({__name:"Error",setup(n){const l=I(),g=T(),_=S(),y=w(()=>{var a,e,b;return(b=(a=_.state.workspace)==null?void 0:a.name)!=null?b:(e=_.state.workspace)==null?void 0:e.brandName}),d=w(()=>{const{status:a}=l.params;switch(a){case"404":return{status:a,title:r.translate("i18n_page_not_found"),message:r.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:a,title:r.translate("i18n_access_denied"),message:r.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:r.translate("i18n_internal_error"),message:r.translate("i18n_internal_error_message"),showAd:!1}}}),k=()=>{g.push({name:"playerHome"})};return(a,e)=>(c(),x("div",V,[i(t(B),null,{default:s(()=>[o(u(d.value.title),1)]),_:1}),i(t(m),{class:"message"},{default:s(()=>[o(u(d.value.message),1)]),_:1}),d.value.action?(c(),f(t(C),{key:0,type:"link",onClick:k},{default:s(()=>[o(u(d.value.action),1)]),_:1})):p("",!0),d.value.showAd?(c(),f(t(R),{key:1,bordered:!1,class:"card"},{default:s(()=>[E("div",H,[i(h,{style:{"margin-bottom":"10px"}}),i(t(m),null,{default:s(()=>[o("This page is part of "+u(y.value?`the ${y.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),t(_).state.workspace?(c(),f(t(m),{key:0},{default:s(()=>[e[1]||(e[1]=o("Automate your own processes by getting started ",-1)),i(t(N),{href:t(v).HOMEPAGE},{default:s(()=>[...e[0]||(e[0]=[o("here",-1)])]),_:1},8,["href"]),e[2]||(e[2]=o(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}});const L=D(G,[["__scopeId","data-v-522ad0d4"]]);export{L as default};
//# sourceMappingURL=Error.396f432f.js.map
