import{d as t,o as d,ac as o,f as s,u as _,S as r,_ as c}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="6d28bb7e-ba9b-4ee8-9c95-aea045dd51c8",e._sentryDebugIdIdentifier="sentry-dbid-6d28bb7e-ba9b-4ee8-9c95-aea045dd51c8")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",i,[s(_(r))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.b6d40f17.js.map
