import{d as o,o as a,ac as s,e as l,ae as c,ez as n,_ as r}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dd10fb51-387c-4ce4-808e-63baad37e44b",e._sentryDebugIdIdentifier="sentry-dbid-dd10fb51-387c-4ce4-808e-63baad37e44b")}catch{}})();const f=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(e){return(t,d)=>(a(),s("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[c(t.$slots,"default",{},void 0,!0)],2)],2))}});const u=r(f,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout.c12f2ad8.js.map
