import{A as n}from"./index.c68b675a.js";import{d as o,c as a,ac as r,f as c,u as f,ez as d,h as l,o as p,_ as i}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="112afa61-034c-48c2-8bbf-b403454892fc",e._sentryDebugIdIdentifier="sentry-dbid-112afa61-034c-48c2-8bbf-b403454892fc")}catch{}})();const u=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=a(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(_,m)=>e.stepsInfo?(p(),r("nav",{key:0,class:d(["p-steps",{"full-screen":!e.isPreview}])},[c(f(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const I=i(u,[["__scopeId","data-v-58fdd395"]]);export{I as S};
//# sourceMappingURL=Steps.d5e9e2f9.js.map
