import{L as a}from"./Logo.2bc39bab.js";import{d as n,o as d,a as r,u as i}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="85832655-2d30-459f-ad2c-01420e8d3587",e._sentryDebugIdIdentifier="sentry-dbid-85832655-2d30-459f-ad2c-01420e8d3587")}catch{}})();const f="/assets/logo.0faadfa2.svg",c=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,o)=>{var s;return d(),r(a,{"image-url":i(f),"brand-name":"Abstra","hide-text":e.hideText,size:(s=e.size)!=null?s:"small"},null,8,["image-url","hide-text","size"])}}});export{c as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.7d3bd819.js.map
