import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.8a0252f0.js";import{d as i,a as s,u as a,eA as m,o as c}from"./jwt-decode.esm.7c9b757c.js";import"./router.95e6e4b6.js";import"./index.33534fc9.js";import"./fetch.e0faab94.js";import"./record.c6bfac6e.js";import"./SaveButton.4ee075ff.js";import"./ExclamationCircleOutlined.a946d051.js";import"./CrudView.243b212b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.95065a46.js";import"./constants.6f371b22.js";import"./url.e6b61fa1.js";import"./PhDotsThreeVertical.vue.23d4ad15.js";import"./index.b636bb44.js";import"./asyncComputed.29ba9357.js";import"./omniChatStore.8a94c755.js";import"./uuid.60efe701.js";import"./PhCopySimple.vue.c37a5bbd.js";import"./PhPencil.vue.4e45fda4.js";import"./useCodebaseEvents.47288451.js";import"./contracts.generated.5dd1e144.js";import"./index.94f4853b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="b9618ec3-e1cc-4fca-ab65-3f39ed5cd400",o._sentryDebugIdIdentifier="sentry-dbid-b9618ec3-e1cc-4fca-ab65-3f39ed5cd400")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=m().params.projectId,t=new p(r);return(d,f)=>(c(),s(n,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.f38767e3.js.map
