import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.0f3cf312.js";import{d as f,ac as m,f as g,u as n,ec as y,eA as b,o as w,_ as k}from"./jwt-decode.esm.7c9b757c.js";import{u as h}from"./workspaceStore.7d445909.js";import"./CircularLoading.19ad1ccf.js";import"./Logo.2bc39bab.js";import"./string.fea0919a.js";import"./index.94f4853b.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="59c4fe79-cea9-4229-9f3d-420c833c8db2",e._sentryDebugIdIdentifier="sentry-dbid-59c4fe79-cea9-4229-9f3d-420c833c8db2")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=y(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),m("div",v,[g(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-12c690e1"]]);export{C as default};
//# sourceMappingURL=Login.6473c263.js.map
