import{C as t,E as d,K as i,a as b,M as f,c as l,P as y,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.4fb1c75c.js";import"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7bd2e23e-bb91-4e2b-abe8-4d148e96e1f2",e._sentryDebugIdIdentifier="sentry-dbid-7bd2e23e-bb91-4e2b-abe8-4d148e96e1f2")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,b as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.3336149f.js.map
