(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="ffffa417-ed95-4a7c-9f54-9a10835bd293",r._sentryDebugIdIdentifier="sentry-dbid-ffffa417-ed95-4a7c-9f54-9a10835bd293")}catch{}})();var t={"+":["conjugate","add"],"\u2212":["negate","subtract"],"\xD7":["signOf","multiply"],"\xF7":["reciprocal","divide"],"\u2308":["ceiling","greaterOf"],"\u230A":["floor","lesserOf"],"\u2223":["absolute","residue"],"\u2373":["indexGenerate","indexOf"],"?":["roll","deal"],"\u22C6":["exponentiate","toThePowerOf"],"\u235F":["naturalLog","logToTheBase"],"\u25CB":["piTimes","circularFuncs"],"!":["factorial","binomial"],"\u2339":["matrixInverse","matrixDivide"],"<":[null,"lessThan"],"\u2264":[null,"lessThanOrEqual"],"=":[null,"equals"],">":[null,"greaterThan"],"\u2265":[null,"greaterThanOrEqual"],"\u2260":[null,"notEqual"],"\u2261":["depth","match"],"\u2262":[null,"notMatch"],"\u2208":["enlist","membership"],"\u2377":[null,"find"],"\u222A":["unique","union"],"\u2229":[null,"intersection"],"\u223C":["not","without"],"\u2228":[null,"or"],"\u2227":[null,"and"],"\u2371":[null,"nor"],"\u2372":[null,"nand"],"\u2374":["shapeOf","reshape"],",":["ravel","catenate"],"\u236A":[null,"firstAxisCatenate"],"\u233D":["reverse","rotate"],"\u2296":["axis1Reverse","axis1Rotate"],"\u2349":["transpose",null],"\u2191":["first","take"],"\u2193":[null,"drop"],"\u2282":["enclose","partitionWithAxis"],"\u2283":["diclose","pick"],"\u2337":[null,"index"],"\u234B":["gradeUp",null],"\u2352":["gradeDown",null],"\u22A4":["encode",null],"\u22A5":["decode",null],"\u2355":["format","formatByExample"],"\u234E":["execute",null],"\u22A3":["stop","left"],"\u22A2":["pass","right"]},l=/[\.\/⌿⍀¨⍣]/,a=/⍬/,i=/[\+−×÷⌈⌊∣⍳\?⋆⍟○!⌹<≤=>≥≠≡≢∈⍷∪∩∼∨∧⍱⍲⍴,⍪⌽⊖⍉↑↓⊂⊃⌷⍋⍒⊤⊥⍕⍎⊣⊢]/,u=/←/,f=/[⍝#].*$/,o=function(r){var e;return e=!1,function(n){return e=n,n===r?e==="\\":!0}};const s={name:"apl",startState:function(){return{prev:!1,func:!1,op:!1,string:!1,escape:!1}},token:function(r,e){var n;return r.eatSpace()?null:(n=r.next(),n==='"'||n==="'"?(r.eatWhile(o(n)),r.next(),e.prev=!0,"string"):/[\[{\(]/.test(n)?(e.prev=!1,null):/[\]}\)]/.test(n)?(e.prev=!0,null):a.test(n)?(e.prev=!1,"atom"):/[¯\d]/.test(n)?(e.func?(e.func=!1,e.prev=!1):e.prev=!0,r.eatWhile(/[\w\.]/),"number"):l.test(n)||u.test(n)?"operator":i.test(n)?(e.func=!0,e.prev=!1,t[n]?"variableName.function.standard":"variableName.function"):f.test(n)?(r.skipToEnd(),"comment"):n==="\u2218"&&r.peek()==="."?(r.next(),"variableName.function"):(r.eatWhile(/[\w\$_]/),e.prev=!0,"keyword"))}};export{s as apl};
//# sourceMappingURL=apl.a5d32932.js.map
