import"./jwt-decode.esm.7c9b757c.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="84644289-2085-45f6-9254-6ae512f6be14",x._sentryDebugIdIdentifier="sentry-dbid-84644289-2085-45f6-9254-6ae512f6be14")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{r as u};
//# sourceMappingURL=uuid.60efe701.js.map
