import{d as l,eX as i,c as n,o as t,ac as s,h as c,ez as u,t as g,_ as f}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b5a2c967-5ceb-405f-84cd-0294a4d79733",e._sentryDebugIdIdentifier="sentry-dbid-b5a2c967-5ceb-405f-84cd-0294a4d79733")}catch{}})();const m={class:"logo"},_=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){i(d=>({v4521d904:o.value}));const a=e,o=n(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),r=n(()=>`${a.brandName} Logo`);return(d,b)=>(t(),s("div",m,[e.imageUrl?(t(),s("img",{key:0,class:"logo-img",src:e.imageUrl,alt:r.value},null,8,_)):c("",!0),e.hideText?c("",!0):(t(),s("span",{key:1,class:u(e.size)},g(e.brandName),3))]))}});const x=f(y,[["__scopeId","data-v-8f34aac0"]]);export{x as L};
//# sourceMappingURL=Logo.2bc39bab.js.map
