import{P as m}from"./PlayerNavbar.457f5fed.js";import{d as g,eA as c,r as h,c as b,ac as y,u as n,a as k,h as v,e as w,f as L,ec as C,j as I,o as i,_ as N}from"./jwt-decode.esm.7c9b757c.js";import{u as V}from"./workspaceStore.7d445909.js";import"./userStore.9178336d.js";import"./metadata.d5fc4220.js";import"./PhWebhooksLogo.vue.2458f971.js";import"./LoadingOutlined.2a8e794f.js";import"./PhSignOut.vue.354e5bf2.js";import"./index.3a0bf605.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="abf9e11b-339e-4958-9baf-6af67ba59453",o._sentryDebugIdIdentifier="sentry-dbid-abf9e11b-339e-4958-9baf-6af67ba59453")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=C(),t=V(),u=c().path,a=h(null),d=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(s,r)=>{const f=I("RouterView");return i(),y("div",x,[n(t).state.workspace?(i(),k(m,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",B,[L(f)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.b8a53f50.js.map
