import{d as i,c as a,o as d,ac as c,e as u,ae as y,ad as o,ez as r}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="37bb820c-848e-4697-9ca2-2bb780a9f872",e._sentryDebugIdIdentifier="sentry-dbid-37bb820c-848e-4697-9ca2-2bb780a9f872")}catch{}})();const p=i({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,n=a(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),l=a(()=>{var s;return{position:"absolute",inset:0,overflow:"auto",...(s=t.innerStyle)!=null?s:{}}});return(s,f)=>(d(),c("div",{style:o(n.value),class:r(e.outerClass)},[u("div",{style:o(l.value),class:r(e.innerClass)},[y(s.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang.61d4943b.js.map
