import{O as l}from"./workspaceStore.7d445909.js";import{d as c,U as f,ac as u,f as o,b as n,u as a,o as _,g as r,t as s,i as d,A as b,df as p}from"./jwt-decode.esm.7c9b757c.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7bf939ba-f5c3-4a42-93d5-ee6bf6db492f",e._sentryDebugIdIdentifier="sentry-dbid-7bf939ba-f5c3-4a42-93d5-ee6bf6db492f")}catch{}})();const v=c({__name:"OidcLogoutCallback",setup(e){return f(async()=>{await new l().logoutCallback()}),(t,i)=>(_(),u("div",null,[o(a(b),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLogoutCallback.a423aac0.js.map
