import{O as s}from"./OmniChat.193e3b10.js";import{u as a}from"./omniChatStore.8a94c755.js";import{d as c,eA as i,u as t,o as f,a as d,h as u}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="703ba9f1-b833-4004-aceb-0ac1fadefeff",e._sentryDebugIdIdentifier="sentry-dbid-703ba9f1-b833-4004-aceb-0ac1fadefeff")}catch{}})();const _=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=a();return o.init("console",n),(l,p)=>t(o).controller&&t(o).repository?(f(),d(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.afd7aa04.js.map
