import{u as r}from"./userStore.9178336d.js";import{W as n}from"./PlayerConfigProvider.be4efc80.js";import{u as c}from"./workspaceStore.7d445909.js";import{d as f,w as i,u as o,a as d,b as p,h as u,j as l,o as m,f as _}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="3ffec30a-9d74-4060-a177-b5694388cfb3",t._sentryDebugIdIdentifier="sentry-dbid-3ffec30a-9d74-4060-a177-b5694388cfb3")}catch{}})();const v=f({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=l("RouterView");return o(e).state.workspace?(m(),d(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:p(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):u("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.81eedc2c.js.map
