import{i as k}from"./metadata.d5fc4220.js";import{W as v}from"./Watermark.539f2cd5.js";import{F as w}from"./PhArrowSquareOut.vue.5643a79c.js";import{d as x,c as b,r as C,u as e,ac as m,f as p,b as r,h as D,ec as z,o as a,a as n,g as f,t as _,i as I,T as y,aY as B,eB as F,dj as g,eD as T,ez as H,_ as L}from"./jwt-decode.esm.7c9b757c.js";import{u as N}from"./workspaceStore.7d445909.js";import"./index.f33e856a.js";import{L as S}from"./LoadingOutlined.2a8e794f.js";import{C as V}from"./Card.929a13fd.js";import"./PhWebhooksLogo.vue.2458f971.js";import"./constants.6f371b22.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="d4740a39-8329-483a-82c4-28d7a5efc47f",o._sentryDebugIdIdentifier="sentry-dbid-d4740a39-8329-483a-82c4-28d7a5efc47f")}catch{}})();const W={key:0,class:"home-container"},j=x({__name:"Home",setup(o){const i=z(),l=N(),u=b(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),h=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(a(),m("div",W,[p(e(g),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),m(B,{key:1},F(u.value,t=>(a(),n(e(V),{key:t.id,class:H(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>h(t.path,t.id)},{default:r(()=>[p(e(g),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(T(e(k)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(_(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(w),{key:0,size:"20"})):(a(),n(e(S),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(v,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const X=L(j,[["__scopeId","data-v-2dd12c4e"]]);export{X as default};
//# sourceMappingURL=Home.aa36c9f9.js.map
