import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.7d3bd819.js";import{B as m}from"./BaseLayout.44e83a23.js";import{d as l,al as y,c8 as v,_ as u,b4 as b,b5 as g,o as _,ac as h,e as a,ad as n,U as w,a as S,b as s,eA as L,ec as k,f as i,u as x}from"./jwt-decode.esm.7c9b757c.js";import{u as B}from"./editor.d5865274.js";import{A as I}from"./index.2afdfa89.js";import"./Logo.2bc39bab.js";import"./router.6dc4e09a.js";import"./workspaceStore.7d445909.js";import"./userStore.9178336d.js";import"./url.e6b61fa1.js";import"./colorHelpers.b8c57893.js";import"./useCodebaseEvents.47288451.js";import"./contracts.generated.5dd1e144.js";import"./index.33534fc9.js";import"./constants.6f371b22.js";import"./linters.a3edae2c.js";import"./asyncComputed.29ba9357.js";import"./index.b636bb44.js";import"./index.3a0bf605.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f7d3e0e2-a31b-4130-9bd1-9f1d414cd3de",e._sentryDebugIdIdentifier="sentry-dbid-f7d3e0e2-a31b-4130-9bd1-9f1d414cd3de")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function A(e,o,r,d,c,p){return b((_(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const D=u($,[["render",A],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const o=L(),r=k(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){r.push({name:"error"});return}await d.createLogin(t).then(c),r.push({name:"editor"})}),(t,z)=>(_(),S(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[a("div",R,[i(D)])]),_:1}))}});const ee=u(j,[["__scopeId","data-v-d2a19803"]]);export{ee as default};
//# sourceMappingURL=ProjectLogin.3ccd50bf.js.map
