import{d as y,c as b,a as d,b as a,u as n,eY as r,ew as g,o as i,f as l,dj as p,ae as u,h as c,eZ as m,bY as f,b0 as k}from"./jwt-decode.esm.7c9b757c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="740254cd-7049-4281-9941-fd6c2eec1e87",e._sentryDebugIdIdentifier="sentry-dbid-740254cd-7049-4281-9941-fd6c2eec1e87")}catch{}})();const w=y({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(e){const t=b(()=>o.disabledTooltip&&o.disabled?o.disabledTooltip:o.tooltip),o=e;return(s,B)=>t.value?(i(),d(n(k),{key:0,title:t.value},{default:a(()=>[l(n(f),r(m(s.$props)),{default:a(()=>[l(n(p),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[e.loading?c("",!0):u(s.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(i(),d(n(f),r(g({key:1},s.$props)),{default:a(()=>[l(n(p),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[e.loading?c("",!0):u(s.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.d8bcc7e4.js.map
